==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property customResponse Defines a custom response for the web request. See `custom_response` below for details.
 */
public data class
WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs(
    public val customResponse:
    Output<WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockCustomResponseArgs>? =
        null,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs> {
    override fun toJava():
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs =
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs.builder()
            .customResponse(
                customResponse?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs].
 */
@PulumiTagMarker
public class
WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgsBuilder
internal constructor() {
    private var customResponse:
        Output<WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockCustomResponseArgs>? =
        null

    /**
     * @param value Defines a custom response for the web request. See `custom_response` below for details.
     */
    @JvmName("qkilfbtmqoinsjjw")
    public suspend
    fun customResponse(`value`: Output<WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockCustomResponseArgs>) {
        this.customResponse = value
    }

    /**
     * @param value Defines a custom response for the web request. See `custom_response` below for details.
     */
    @JvmName("sabeepaknyshxfpu")
    public suspend
    fun customResponse(`value`: WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockCustomResponseArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customResponse = mapped
    }

    /**
     * @param argument Defines a custom response for the web request. See `custom_response` below for details.
     */
    @JvmName("vljpvbhmgdoqhwri")
    public suspend
    fun customResponse(argument: suspend WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockCustomResponseArgsBuilder.() -> Unit) {
        val toBeMapped =
            WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockCustomResponseArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.customResponse = mapped
    }

    internal fun build():
        WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs =
        WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs(
            customResponse = customResponse,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property customResponse Defines a custom response for the web request. See `custom_response` below for details.
 */
public data class
WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs(
    public val customResponse: Output<WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockCustomResponseArgs>? =
        null,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs =
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs.builder()
            .customResponse(
                customResponse?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs].
 */
@PulumiTagMarker
public class
WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgsBuilder
internal constructor() {
    private var customResponse:
        Output<WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockCustomResponseArgs>? =
        null

    /**
     * @param value Defines a custom response for the web request. See `custom_response` below for details.
     */
    @JvmName("vjgrtxvawbjptokx")
    public suspend fun customResponse(`value`: Output<WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockCustomResponseArgs>) {
        this.customResponse = value
    }

    /**
     * @param value Defines a custom response for the web request. See `custom_response` below for details.
     */
    @JvmName("ohlskipqoklliwfq")
    public suspend fun customResponse(`value`: WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockCustomResponseArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customResponse = mapped
    }

    /**
     * @param argument Defines a custom response for the web request. See `custom_response` below for details.
     */
    @JvmName("ityijmayfnmfelfb")
    public suspend fun customResponse(argument: suspend WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockCustomResponseArgsBuilder.() -> Unit) {
        val toBeMapped =
            WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockCustomResponseArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.customResponse = mapped
    }

    internal fun build(): WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs =
        WebAclRuleStatementRuleGroupReferenceStatementRuleActionOverrideActionToUseBlockArgs(
            customResponse = customResponse,
        )
}
